﻿using System.Windows.Forms;

using Arction.WinForms.Charting;
using Arction.WinForms.Charting.Axes;
using Arction.WinForms.Charting.SeriesXY;
using Arction.WinForms.Charting.Views.ViewXY;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 차트
        /// </summary>
        private LightningChartUltimate chart = null;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            InitializeChart();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 차트 초기화하기 - InitializeChart()

        /// <summary>
        /// 차트 초기화하기
        /// </summary>
        private void InitializeChart()
        {
            this.chart = new LightningChartUltimate();
            
            this.chart.BeginUpdate();
            
            this.chart.Name   = "chart";
            this.chart.Parent = this;
            this.chart.Dock   = DockStyle.Fill;

            this.chart.Title.Font = Font;
            this.chart.Title.Text = "선/막대 차트";

            ViewXY viewXY = this.chart.ViewXY;

            viewXY.BarViewOptions.Grouping = BarsGrouping.ByLocation;

            AxisX axisX = viewXY.XAxes[0];

            axisX.Title.Font = Font;
            axisX.Title.Text = "X축";
            axisX.ValueType  = AxisValueType.Number;
            axisX.ScrollMode = XAxisScrollMode.None;

            axisX.SetRange(0, 11);

            AxisY axisY = viewXY.YAxes[0];

            axisY.Title.Font = Font;
            axisY.Title.Text = "Y축";

            axisY.SetRange(0, 60);

            ChartHelper.SetDarkFlatStyle(this.chart);

            int pointCount = 10;

            double[] xValueArray = new double[] { 1, 2, 3, 4, 5, 6, 7, 8, 9, 10 };
            double[] yValueArray = new double[] { 10, 20, 35, 50, 58, 45, 30, 25, 20, 5 };

            PointLineSeries pointLineSeries = new PointLineSeries(viewXY, axisX, axisY);

            pointLineSeries.Title.Text    = "선";
            pointLineSeries.PointsVisible = true;

            pointLineSeries.AddPoints(xValueArray, yValueArray, false);

            viewXY.PointLineSeries.Add(pointLineSeries);

            BarSeries barSeries = new BarSeries(viewXY, axisX, axisY);

            barSeries.Title.Text = "막대";

            BarSeriesValue[] barSeriesValueArray = new BarSeriesValue[10];

            for(int i = 0; i < pointCount; i++)
            {
                barSeriesValueArray[i].Location = xValueArray[i];
                barSeriesValueArray[i].Value    = yValueArray[i];
            }

            barSeries.Values = barSeriesValueArray;

            viewXY.BarSeries.Add(barSeries);

            LegendBoxXY legendBoxXY = viewXY.LegendBoxes[0];

            legendBoxXY.Position = LegendBoxPositionXY.SegmentBottomRight;

            this.chart.EndUpdate();
        }

        #endregion
    }
}